#[repr(transparent)]pub struct CanonicalCombiningClassULE(pub <u8 as AsULE>::ULE);Expand description
ULE type for CanonicalCombiningClass
Tuple Fields
0: <u8 as AsULE>::ULETrait Implementations
Sourceimpl Clone for CanonicalCombiningClassULE
impl Clone for CanonicalCombiningClassULE
Sourcefn clone(&self) -> CanonicalCombiningClassULE
fn clone(&self) -> CanonicalCombiningClassULE
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Ord for CanonicalCombiningClassULE
impl Ord for CanonicalCombiningClassULE
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CanonicalCombiningClassULE
impl PartialEq for CanonicalCombiningClassULE
Sourcefn eq(&self, other: &CanonicalCombiningClassULE) -> bool
fn eq(&self, other: &CanonicalCombiningClassULE) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for CanonicalCombiningClassULE
impl PartialOrd for CanonicalCombiningClassULE
Sourceimpl ULE for CanonicalCombiningClassULE
impl ULE for CanonicalCombiningClassULE
Sourcefn validate_byte_slice(bytes: &[u8]) -> Result<(), ZeroVecError>
fn validate_byte_slice(bytes: &[u8]) -> Result<(), ZeroVecError>
Validates a byte slice,
&[u8]. Read moreSourcefn parse_byte_slice(bytes: &[u8]) -> Result<&[Self], ZeroVecError>
fn parse_byte_slice(bytes: &[u8]) -> Result<&[Self], ZeroVecError>
Sourceunsafe fn from_byte_slice_unchecked(bytes: &[u8]) -> &[Self]
unsafe fn from_byte_slice_unchecked(bytes: &[u8]) -> &[Self]
Takes a byte slice,
&[u8], and return it as &[Self] with the same lifetime, assuming
that this byte slice has previously been run through Self::parse_byte_slice() with
success. Read moreimpl Copy for CanonicalCombiningClassULE
impl Eq for CanonicalCombiningClassULE
impl StructuralPartialEq for CanonicalCombiningClassULE